@@ -27,12 +27,16 @@ from .._impl import (
     module_ModuleVersionDefinition as ModuleVersionDefinition,
     module_ModuleVersionMetadata as ModuleVersionMetadata,
     module_ParameterName as ParameterName,
+    module_SearchModuleApplicationsQuery as SearchModuleApplicationsQuery,
+    module_SearchModuleApplicationsQueryVisitor as SearchModuleApplicationsQueryVisitor,
     module_SearchModuleApplicationsRequest as SearchModuleApplicationsRequest,
     module_SearchModuleApplicationsResponse as SearchModuleApplicationsResponse,
     module_SearchModulesQuery as SearchModulesQuery,
     module_SearchModulesQueryVisitor as SearchModulesQueryVisitor,
     module_SearchModulesRequest as SearchModulesRequest,
     module_SearchModulesResponse as SearchModulesResponse,
+    module_SearchModulesSortField as SearchModulesSortField,
+    module_SearchModulesSortOptions as SearchModulesSortOptions,
     module_SemanticVersion as SemanticVersion,
     module_UnapplyModuleRequest as UnapplyModuleRequest,
     module_UnapplyModuleResponse as UnapplyModuleResponse,
@@ -68,12 +72,16 @@ __all__ = [
     'ModuleVersionDefinition',
     'ModuleVersionMetadata',
     'ParameterName',
+    'SearchModuleApplicationsQuery',
+    'SearchModuleApplicationsQueryVisitor',
     'SearchModuleApplicationsRequest',
     'SearchModuleApplicationsResponse',
     'SearchModulesQuery',
     'SearchModulesQueryVisitor',
     'SearchModulesRequest',
     'SearchModulesResponse',
+    'SearchModulesSortField',
+    'SearchModulesSortOptions',
     'SemanticVersion',
     'UnapplyModuleRequest',
     'UnapplyModuleResponse',
